#include "reader.h"

void Reader::run()
{
    QString audio = this->filename;
    audio.chop(3);
    audio.append("wav");
    audioFile = new QFile(audio);
    if (!audioFile->open(QIODevice::ReadWrite))
        qDebug()<<"cannot write to file";
    else
    {
        QString program = "flite"; //espeak
        QStringList arguments;

        arguments << "-voice" << "kal16" << "-f" << filename << "-o" << audio;
        qDebug()<<arguments;
        QProcess *myProcess = new QProcess();

      //  file = audio;

        myProcess->start(program, arguments);
        myProcess->waitForFinished();

        audioFile->close();
        this->finished();

    }
}

void Reader::setFileName(QString filename)
{
    this->filename = filename;
}
